PackedZipRemoteDataset
======================

.. currentmodule:: pykeen.datasets.base

.. autoclass:: PackedZipRemoteDataset
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~PackedZipRemoteDataset.head_column
      ~PackedZipRemoteDataset.header
      ~PackedZipRemoteDataset.relation_column
      ~PackedZipRemoteDataset.sep
      ~PackedZipRemoteDataset.tail_column

   .. rubric:: Attributes Documentation

   .. autoattribute:: head_column
   .. autoattribute:: header
   .. autoattribute:: relation_column
   .. autoattribute:: sep
   .. autoattribute:: tail_column
